@@ -61,9 +61,16 @@ class PraatLoader:
             self.updatelog('%s' % str(com))
         orig = os.getuid()
         os.setuid(1000)
+        if self.debug:
+            self.updatelog('orignal user: %s' % str(orig))
+            self.updatelog('now user: %s' % str(os.getuid()))
         p = subprocess.Popen(com,stdout=subprocess.PIPE,stderr=subprocess.PIPE,stdin=subprocess.PIPE)
         stdout, stderr = p.communicate()
+        if self.debug:
+            self.updatelog('now user: %s' % str(os.getuid())
         os.setuid(orig)
+        if self.debug:
+            self.updatelog('now user: %s' % str(os.getuid())
         if self.debug:
             self.updatelog('stdout: %s' % str(stdout))
             self.updatelog('stderr: %s' % str(stderr))
